@@ -1,7 +1,7 @@
 import asyncio
 import logging
 from abc import abstractmethod
-from typing import Any, Union
+from typing import Any, Optional, Union
 
 from aiomisc import PeriodicCallback, Service
 
@@ -29,7 +29,7 @@ class PeriodicService(Service):
         self.periodic.start(self.interval, delay=self.delay, loop=self.loop)
         log.info("Periodic service %s started", self)
 
-    async def stop(self, err: Exception = None) -> None:
+    async def stop(self, err: Optional[Exception] = None) -> None:
         await asyncio.gather(self.periodic.stop(), return_exceptions=True)
         log.info("Periodic service %s is stopped", self)
 
