@@ -20,7 +20,7 @@ def _process_inner(
     log_format: str,
     start_event: synchronize.Event,
     stop_event: synchronize.Event,
-    **kwargs: Any
+    **kwargs: Any,
 ) -> None:
     basic_config(level=log_level, log_format=log_format)
     start_event.set()
@@ -38,7 +38,6 @@ class ProcessService(Service):
     _process_start_event: synchronize.Event
     _process_stop_event: synchronize.Event
     _lock: Lock
-    _instance_params: Dict[str, Any]
 
     def get_process_kwargs(self) -> Dict[str, Any]:
         return {}
@@ -101,7 +100,7 @@ class ProcessService(Service):
             self.__class__.__name__, hex(id(self)), self.name, pid,
         )
 
-    async def stop(self, exception: Exception = None) -> Any:
+    async def stop(self, exception: Optional[Exception] = None) -> Any:
         if not self._is_alive():
             return
 
@@ -117,18 +116,16 @@ class ProcessService(Service):
         )
 
         if stop_result:
-            stop_result = (
-                await self.loop.run_in_executor(
-                    None, process.join, self.process_stop_timeout,
-                )
-            ) is not None
+            await self.loop.run_in_executor(
+                None, process.join, self.process_stop_timeout,
+            )
 
         if not stop_result and process.is_alive():
             process.kill()
             log.warning(
                 f"The process {process.pid} didn't stop for "
                 f"{self.process_stop_timeout} seconds "
-                f"and had been killed.",
+                "and had been killed.",
             )
 
 
@@ -157,7 +154,7 @@ class RespawningProcessService(ProcessService, ABC):
             self.process_poll_timeout,
         )
 
-    async def stop(self, exception: Exception = None) -> Any:
+    async def stop(self, exception: Optional[Exception] = None) -> Any:
         await self._supervisor.stop()
         await super().stop(exception)
 
